==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/FinancialCalculationSupportingCalculationsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnSupportingCalculationDescriptionMetadata } from "./ColumnSupportingCalculationDescriptionMetadata";
import { DataSourceSupportingCalculationDescriptionMetadata } from "./DataSourceSupportingCalculationDescriptionMetadata";
import { FinancialCalculationSupportingCalculationsDescription } from "./FinancialCalculationSupportingCalculationsDescription";
/**
 * @hidden
 */
var FinancialCalculationSupportingCalculationsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FinancialCalculationSupportingCalculationsDescriptionMetadata, _super);
    function FinancialCalculationSupportingCalculationsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialCalculationSupportingCalculationsDescriptionMetadata.b = function (a) {
        if (FinancialCalculationSupportingCalculationsDescriptionMetadata.a == null) {
            FinancialCalculationSupportingCalculationsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialCalculationSupportingCalculationsDescriptionMetadata.c(FinancialCalculationSupportingCalculationsDescriptionMetadata.a);
        }
        if (a.j(FinancialCalculationSupportingCalculationsDescriptionMetadata.a)) {
            return;
        }
        a.y(FinancialCalculationSupportingCalculationsDescriptionMetadata.a);
        ColumnSupportingCalculationDescriptionMetadata.d(a);
        DataSourceSupportingCalculationDescriptionMetadata.d(a);
    };
    FinancialCalculationSupportingCalculationsDescriptionMetadata.c = function (a) {
        a.item("EMA", "ExportedType:ColumnSupportingCalculation");
        a.item("SMA", "ExportedType:ColumnSupportingCalculation");
        a.item("STDEV", "ExportedType:ColumnSupportingCalculation");
        a.item("MovingSum", "ExportedType:ColumnSupportingCalculation");
        a.item("ShortVolumeOscillatorAverage", "ExportedType:DataSourceSupportingCalculation");
        a.item("LongVolumeOscillatorAverage", "ExportedType:DataSourceSupportingCalculation");
        a.item("ShortPriceOscillatorAverage", "ExportedType:DataSourceSupportingCalculation");
        a.item("LongPriceOscillatorAverage", "ExportedType:DataSourceSupportingCalculation");
        a.item("MakeSafeRef", "(w:MakeSafe,wf:MakeSafe)MethodRef");
    };
    FinancialCalculationSupportingCalculationsDescriptionMetadata.d = function (a) {
        FinancialCalculationSupportingCalculationsDescriptionMetadata.b(a);
        a.aa("FinancialCalculationSupportingCalculations", function () { return new FinancialCalculationSupportingCalculationsDescription(); });
        a.z("FinancialCalculationSupportingCalculations", FinancialCalculationSupportingCalculationsDescriptionMetadata.a);
    };
    FinancialCalculationSupportingCalculationsDescriptionMetadata.$t = markType(FinancialCalculationSupportingCalculationsDescriptionMetadata, 'FinancialCalculationSupportingCalculationsDescriptionMetadata');
    FinancialCalculationSupportingCalculationsDescriptionMetadata.a = null;
    return FinancialCalculationSupportingCalculationsDescriptionMetadata;
}(Base));
export { FinancialCalculationSupportingCalculationsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/FinancialCalculationSupportingCalculationsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnSupportingCalculationDescriptionMetadata } from "./ColumnSupportingCalculationDescriptionMetadata";
import { DataSourceSupportingCalculationDescriptionMetadata } from "./DataSourceSupportingCalculationDescriptionMetadata";
import { FinancialCalculationSupportingCalculationsDescription } from "./FinancialCalculationSupportingCalculationsDescription";
/**
 * @hidden
 */
var FinancialCalculationSupportingCalculationsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FinancialCalculationSupportingCalculationsDescriptionMetadata, _super);
    function FinancialCalculationSupportingCalculationsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialCalculationSupportingCalculationsDescriptionMetadata.b = function (a) {
        if (FinancialCalculationSupportingCalculationsDescriptionMetadata.a == null) {
            FinancialCalculationSupportingCalculationsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialCalculationSupportingCalculationsDescriptionMetadata.c(FinancialCalculationSupportingCalculationsDescriptionMetadata.a);
        }
        if (a.k(FinancialCalculationSupportingCalculationsDescriptionMetadata.a)) {
            return;
        }
        a.aa(FinancialCalculationSupportingCalculationsDescriptionMetadata.a);
        ColumnSupportingCalculationDescriptionMetadata.d(a);
        DataSourceSupportingCalculationDescriptionMetadata.d(a);
    };
    FinancialCalculationSupportingCalculationsDescriptionMetadata.c = function (a) {
        a.item("EMA", "ExportedType:ColumnSupportingCalculation");
        a.item("SMA", "ExportedType:ColumnSupportingCalculation");
        a.item("STDEV", "ExportedType:ColumnSupportingCalculation");
        a.item("MovingSum", "ExportedType:ColumnSupportingCalculation");
        a.item("ShortVolumeOscillatorAverage", "ExportedType:DataSourceSupportingCalculation");
        a.item("LongVolumeOscillatorAverage", "ExportedType:DataSourceSupportingCalculation");
        a.item("ShortPriceOscillatorAverage", "ExportedType:DataSourceSupportingCalculation");
        a.item("LongPriceOscillatorAverage", "ExportedType:DataSourceSupportingCalculation");
        a.item("MakeSafeRef", "(w:MakeSafe,wf:MakeSafe)MethodRef");
    };
    FinancialCalculationSupportingCalculationsDescriptionMetadata.d = function (a) {
        FinancialCalculationSupportingCalculationsDescriptionMetadata.b(a);
        a.ac("FinancialCalculationSupportingCalculations", function () { return new FinancialCalculationSupportingCalculationsDescription(); });
        a.ab("FinancialCalculationSupportingCalculations", FinancialCalculationSupportingCalculationsDescriptionMetadata.a);
    };
    FinancialCalculationSupportingCalculationsDescriptionMetadata.$t = markType(FinancialCalculationSupportingCalculationsDescriptionMetadata, 'FinancialCalculationSupportingCalculationsDescriptionMetadata');
    FinancialCalculationSupportingCalculationsDescriptionMetadata.a = null;
    return FinancialCalculationSupportingCalculationsDescriptionMetadata;
}(Base));
export { FinancialCalculationSupportingCalculationsDescriptionMetadata };
